---
title: Planck-Tapered Conditional Ratio Power Law
description: API reference for the tapered conditional ratio power law.
---

::: gwmock_pop.distributions.planck_tapered_conditional_ratio_power_law
